@@ -10,6 +10,8 @@ MainWindow::MainWindow(QWidget *parent) :
     metaDataTimer = new QTimer;
     connect(metaDataTimer, SIGNAL(timeout()), SLOT(getMetaData()));
 
+    alternateBoolean = true;
+
     readSettings();
 
     ui->setupUi(this);
@@ -45,12 +47,22 @@ MainWindow::MainWindow(QWidget *parent) :
                                          "Terminated",
                                          this, SLOT(callEnded()));
 
+    QDBusConnection::systemBus().connect(QString(),
+                                         "/org/freedesktop/Hal/devices/platform_cam_focus",
+                                         "org.freedesktop.Hal.Device",
+                                         "PropertyModified",
+                                         this, SLOT(focusButtonPressed()));
+
     if (inizializeAtStartUp)
     {
         qDebug()<<"Inizialize at start up is enabled, starting radio.";
         startRadio();
     }
 
+    fileSystemWatcher = new QFileSystemWatcher;
+    fileSystemWatcher->addPath("/sys/devices/platform/gpio-switch/cam_focus/disable");
+    connect(fileSystemWatcher, SIGNAL(fileChanged(QString)), SLOT(setFocusButtonActive()));
+
 }
 
 MainWindow::~MainWindow()
@@ -221,6 +233,7 @@ void MainWindow::readSettings()
     currentSet=settings.value("currentSet", 1).toInt();
     resumeAfterCall=settings.value("resumeAfterCall", false).toBool();
     inizializeAtStartUp=settings.value("inizializeAtStartUp", false).toBool();
+    cameraFocusButtonUsed=settings.value("cameraFocusButtonUsed", true).toBool();
 
     QSettings setSettings("qradio", "set" + QString::number(currentSet));
     quickAccessButtonsTextList = setSettings.value("quickAccessButtonsTextList", QStringList()<<"87.6"<< "101.0"<< "99.5"<< "102.3").toStringList();
@@ -314,6 +327,7 @@ void MainWindow::on_volumeSlider_valueChanged(int value)
     if (ui->actionSpeakers->isChecked())
     {
         int volume = ui->volumeSlider->value();
+        //volume = (volume/100.0)*118;         //Needed to get max volume for speakers, hurts ears.
         QString program = "sh /opt/qradio/speakerVolume.sh ";
         program.append(QString::number(volume));
 
@@ -555,7 +569,7 @@ void MainWindow::on_actionManual_triggered()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                    tr("<h2>QRadio 0.4.4</h2>"
+                    tr("<h2>QRadio 0.4.5</h2>"
                        "<p>"
                        "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 }
@@ -694,3 +708,52 @@ void MainWindow::callEnded()
     metaDataTimer->start(10000);
     setWidgetsEnabled(true);
 }
+
+void MainWindow::focusButtonPressed()
+{
+    qDebug()<<"Focus button pressed";
+
+    if (radio==0)
+    {
+        return;
+    }
+
+    if (!cameraFocusButtonUsed)
+    {
+        qDebug()<<"Camera Focus Button option not enabled";
+        return;
+    }
+
+    if (alternateBoolean == true)
+    {
+        system("cat /sys/devices/platform/gpio-switch/cam_focus/state");
+        on_nextStationButton_clicked();
+        alternateBoolean = false;
+    }
+    else
+    {
+        alternateBoolean = true;
+    }
+
+}
+
+void MainWindow::setFocusButtonActive()
+{
+    if (!cameraFocusButtonUsed) return;
+
+    qDebug()<<"Forcing focus button active";
+
+    QFile file("/sys/devices/platform/gpio-switch/cam_focus/disable");
+    file.open(QIODevice::ReadOnly | QIODevice::Text);
+    QTextStream t( &file );
+    QString value;
+    value = t.readLine();
+    qDebug()<<"Disable status: "<<value;
+    file.close();
+
+    if (value == "0")
+    {
+        return;
+    }
+    system("echo 'echo 0 > /sys/devices/platform/gpio-switch/cam_focus/disable' | root");
+}
