@@ -8,6 +8,7 @@
 
 #include <QDebug>
 #include <QFile>
+#include <QFileSystemWatcher>
 #include <QInputDialog>
 #include <QListWidgetItem>
 #include <QMessageBox>
@@ -55,6 +56,11 @@ private:
     bool inizializeAtStartUp;
     QStringList quickAccessButtonsTextList;
     QStringList stationsList;
+    bool cameraFocusButtonUsed;
+
+    bool alternateBoolean;
+
+    QFileSystemWatcher *fileSystemWatcher;
 
     void readSettings();
     void saveSettings();
@@ -106,6 +112,9 @@ private slots:
 
     void callIncoming();
     void callEnded();
+
+    void focusButtonPressed();
+    void setFocusButtonActive();
 };
 
 #endif // MAINWINDOW_H
